@@ -1,13 +1,16 @@
 import ast
-from typing import Type
+from typing import TYPE_CHECKING
 
 from yastyleguide.types import ERROR_GENERATOR
 
+if TYPE_CHECKING:
+    from yastyleguide.plugin import YASPlugin
+
 
 class BaseChecker:
     """Base checker class."""
 
-    base_visitor: Type[ast.NodeVisitor]
+    base_visitor: type[ast.NodeVisitor]
 
     def __init__(self, tree: ast.AST, **kwargs):
         """Create base checker with visitor and run it on tree.
@@ -20,7 +23,7 @@ class BaseChecker:
         self.visitor.visit(tree)
         self._set_options(**kwargs)
 
-    def _set_options(self, **kwargs):
+    def _set_options(self, **kwargs) -> None:
         """Set checker options."""
         ...
 
@@ -28,7 +31,7 @@ class BaseChecker:
         """Rule for linter errors generator.
 
         Raises:
-            NotImplementedError: There is no inplementation here.
+            NotImplementedError: There is no implementation here.
 
         Yield:
             ERROR_GENERATOR: errors in flake format.
@@ -36,11 +39,11 @@ class BaseChecker:
         raise NotImplementedError
 
     @classmethod
-    def from_plugin(cls: Type["BaseChecker"], plugin) -> "BaseChecker":
+    def from_plugin(cls: type["BaseChecker"], plugin: "YASPlugin") -> "BaseChecker":
         """Class method for initialization checker.
 
         Args:
-            plugin: plugin with tree and options.
+            plugin("YASPlugin"): plugin with tree and options.
 
         Returns:
             "BaseChecker": checker object
