@@ -1,5 +1,3 @@
-from typing import Dict
-
 from yastyleguide.types import ERROR_GENERATOR
 from yastyleguide.visitors import ComplexityVisitor
 
@@ -13,7 +11,9 @@ class LineComplexityChecker(BaseChecker):
     template = "YAS201 Line is to complex, {0} > {1}. To many ast nodes per line."
     max_line_complexity: int
 
-    def _set_options(self, max_line_complexity: int = 8, **kwargs):
+    def _set_options(
+        self, max_line_complexity: int = 8, **kwargs: dict[str, int]
+    ) -> None:
         """Set checker options.
 
         Args:
@@ -28,7 +28,7 @@ class LineComplexityChecker(BaseChecker):
             ERROR_GENERATOR: errors in flake format.
         """
         # We use one implementation of NodeVisitor
-        line_score: Dict[int, int] = self.visitor.line_score  # type: ignore
+        line_score: dict[int, int] = self.visitor.line_score  # type: ignore
         max_complexity = self.max_line_complexity
         yield from (
             (lineno, 0, self.template.format(score, max_complexity), type(self.visitor))
