@@ -1,8 +1,6 @@
 import ast
 from collections import defaultdict
-from typing import Dict
 
-from .node_name import name
 from .stop_node import stop_node
 from .use_node import use_node
 
@@ -22,10 +20,10 @@ class ComplexityVisitor(ast.NodeVisitor):
 
     def __init__(self):
         """Create line visitor."""
-        self.line_score: Dict[int, int] = defaultdict(int)
-        self.unit_count: Dict[str, int] = defaultdict(int)
+        self.line_score: dict[int, int] = defaultdict(int)
+        self.unit_count: dict[str, int] = defaultdict(int)
 
-    def visit(self, node: ast.AST):
+    def visit(self, node: ast.AST) -> None:
         """Method for calculating nodes in each line.
 
         I overload standart visit method.
@@ -34,7 +32,6 @@ class ComplexityVisitor(ast.NodeVisitor):
             node (ast.AST): ast node.
         """
         lineno = getattr(node, "lineno", None)
-        node_type = name(node)
 
         if lineno and use_node(node):
             self.line_score[lineno] += 1
@@ -42,7 +39,4 @@ class ComplexityVisitor(ast.NodeVisitor):
         if stop_node(node):
             return
 
-        if node_type in self.DEFINITIONS:
-            self.unit_count[self.DEFINITIONS[node_type]] += 1
-
         super().visit(node)
